Learn R Programming

bssm (version 1.1.5)

ar1_ng: Non-Gaussian model with AR(1) latent process

Description

Constructs a simple non-Gaussian model where the state dynamics follow an AR(1) process.

Usage

ar1_ng(y, rho, sigma, mu, distribution, phi, u = 1, beta, xreg = NULL)

Arguments

y

Vector or a ts object of observations.

rho

prior for autoregressive coefficient.

sigma

Prior for the standard deviation of noise of the AR-process.

mu

A fixed value or a prior for the stationary mean of the latent AR(1) process. Parameter is omitted if this is set to 0.

distribution

Distribution of the observed time series. Possible choices are "poisson", "binomial", "gamma", and "negative binomial".

phi

Additional parameter relating to the non-Gaussian distribution. For negative binomial distribution this is the dispersion term, for gamma distribution this is the shape parameter, and for other distributions this is ignored.

u

Constant parameter vector for non-Gaussian models. For Poisson, gamma, and negative binomial distribution, this corresponds to the offset term. For binomial, this is the number of trials.

beta

Prior for the regression coefficients.

xreg

Matrix containing covariates.

Value

Object of class ar1_ng.