This functions returns a list containing mean, standard deviations, standard errors, and effective sample size estimates for parameters and states.
# S3 method for mcmc_output
summary(object, return_se = FALSE, variable = "theta", only_theta = FALSE, ...)Output from run_mcmc
if FALSE (default), computation of standard
errors and effective sample sizes is omitted.
Are the summary statistics computed for either
"theta" (default), "states", or "both"?
Deprecated. If TRUE, summaries are computed only
for hyperparameters theta.
Ignored.
For IS-MCMC two types of standard errors are reported. SE-IS can be regarded as the square root of independent IS variance, whereas SE corresponds to the square root of total asymptotic variance (see Remark 3 of Vihola et al. (2020)).
Vihola, M, Helske, J, Franks, J. Importance sampling type estimators based on approximate marginal Markov chain Monte Carlo. Scand J Statist. 2020; 1-38. https://doi.org/10.1111/sjos.12492