Constructs a simple non-Gaussian model where the state dynamics follow an AR(1) process.
ar1_ng(y, rho, sigma, mu, distribution, phi, u = 1, beta, xreg = NULL)Vector or a ts object of observations.
prior for autoregressive coefficient.
Prior for the standard deviation of noise of the AR-process.
A fixed value or a prior for the stationary mean of the latent AR(1) process. Parameter is omitted if this is set to 0.
Distribution of the observed time series. Possible choices are
"poisson", "binomial", "gamma", and "negative binomial".
Additional parameter relating to the non-Gaussian distribution. For negative binomial distribution this is the dispersion term, for gamma distribution this is the shape parameter, and for other distributions this is ignored.
Constant parameter vector for non-Gaussian models. For Poisson, gamma, and negative binomial distribution, this corresponds to the offset term. For binomial, this is the number of trials.
Prior for the regression coefficients.
Matrix containing covariates.
Object of class ar1_ng.